==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Fermeture du dessin...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Sans titre %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>Chargement...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>Erreur d&apos;importation</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Aucun importateur appropriée trouvée. S&apos;il vous plaît vérifiez le format de fichier et son extension.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>S&apos;il vous plaît vérifiez vos droits d&apos;accès, le format de fichier et l&apos;extension de fichier.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>Le fichier est vide.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>Dessin ouvert :</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>Sans titre %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Voulez-vous enregistrer les modifications que vous avez faites&lt;br&gt;dans le document &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vos modifications seront perdues si vous ne les enregistrez pas.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translation>Fermeture du dessin...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translation>Sans titre</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translation type="obsolete">Sans titre %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation>Ouverture du dessin :</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">Chargement...</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translation>Erreur d&apos;importation</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translation>Impossible d&apos;ouvrir le fichier</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Aucun importateur appropriée trouvée. S&apos;il vous plaît vérifiez le format de fichier et son extension.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation>Fichier introuvable.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>S&apos;il vous plaît vérifiez vos droits d&apos;accès, le format de fichier et l&apos;extension de fichier.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation>Importer échoué.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>Le fichier est vide.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>Dessin chargé avec succès :</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">Dessin ouvert :</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>Sans titre %1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>Lecture seule</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translation>Voulez-vous enregistrer les modifications que vous avez faites&lt;br&gt;dans le document &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Vos modifications seront perdues si vous ne les enregistrez pas.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
</context>
</TS>
